@@ -4,7 +4,7 @@ from sklearn.neighbors import KNeighborsClassifier
 from sklearn.svm import SVC
 
 
-def GetMandP(model_name):
+def GetTraMandP(model_name):
 
 
     # 模型定义
